==> just_mf_map-0.0.2.tar.gz: lib/src/controller.dart <==
part of just_mf_map_flutter;

class MFMapViewController {
  final int mapId;
  final _MFMapViewState _mapState;
  final MethodChannel _channel;

  MFMapViewController._(this.mapId, this._mapState, this._channel) {
    _channel.setMethodCallHandler((call) => _handleMethodCall(call));
  }

  /// Initialize control of a [Map4d] with [mapId].
  ///
  /// Mainly for internal use when instantiating a [MFMapViewController] passed
  /// in [Map4dMap.onMapCreated] callback.
  static Future<MFMapViewController> init(
    int mapId,
    _MFMapViewState mapState,
  ) async {
    final channel = MethodChannel('plugin:map4d-map-view-type_$mapId');
    return MFMapViewController._(mapId, mapState, channel);
  }

  Future<dynamic> _handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case 'camera#onMoveStarted':
        if (_mapState.widget.onCameraMoveStarted != null) {
          _mapState.widget.onCameraMoveStarted!();
        }
        break;
      case 'camera#onMove':
        if (_mapState.widget.onCameraMove != null) {
          final position = MFCameraPosition.fromMap(call.arguments['position']);
          _mapState.widget.onCameraMove!(position!);
        }
        break;
      case 'camera#onIdle':
        if (_mapState.widget.onCameraIdle != null) {
          _mapState.widget.onCameraIdle!();
        }
        break;
      case 'map#didTapAtCoordinate':
        if (_mapState.widget.onTap != null) {
          final coordinate = MFLatLng.fromJson(call.arguments['coordinate']);
          _mapState.widget.onTap!(coordinate!);
        }
        break;
      case 'map#onTapPOI':
        final onPOITap = _mapState.widget.onPOITap;
        if (onPOITap != null) {
          final String placeId = call.arguments['placeId'];
          final String name = call.arguments['name'];
          final MFLatLng location = MFLatLng.fromJson(call.arguments['location'])!;
          onPOITap(placeId, name, location);
        }
        break;
      case 'map#onTapBuilding':
        final onBuildingTap = _mapState.widget.onBuildingTap;
        if (onBuildingTap != null) {
          final String buildingId = call.arguments['buildingId'];
          final String name = call.arguments['name'];
          final MFLatLng location = MFLatLng.fromJson(call.arguments['location'])!;
          onBuildingTap(buildingId, name, location);
        }
        break;
      case 'map#onModeChange':
        final is3DMode = call.arguments['is3DMode'];
        _mapState.widget.onModeChange!(is3DMode);
        break;
      default:
        print('Unknow callback method: ${call.method}');
    }
  }

  /// Returns the current zoom level of the map
  Future<double> getZoomLevel() async {
    return (await _channel.invokeMethod<double>('map#getZoomLevel'))!;
  }

  Future<void> moveCamera(MFCameraUpdate cameraUpdate) {
    return _channel.invokeMethod<void>('camera#move',
        <String, dynamic>{'cameraUpdate': cameraUpdate.toJson()});
  }

  Future<void> animateCamera(MFCameraUpdate cameraUpdate) {
    return _channel.invokeMethod<void>('camera#animate',
        <String, Object>{'cameraUpdate': cameraUpdate.toJson()});
  }

  Future<MFCameraPosition> cameraForBounds(MFLatLngBounds bounds, { double padding = 0 }) async {
    final Map<String, dynamic> cameraPosition = (await _channel.invokeMapMethod<String, dynamic>('map#cameraForBounds',
        <String, dynamic>{'bounds': bounds.toJson(), 'padding': padding}))!;
    return MFCameraPosition.fromMap(cameraPosition)!;
  }

  Future<MFCameraPosition?> getCameraPosition() async {
    final Map<String, dynamic> cameraPosition = (await _channel.invokeMapMethod<String, dynamic>('map#getCameraPosition'))!;
    return MFCameraPosition.fromMap(cameraPosition);
  }

  Future<void> fitBounds(MFLatLngBounds bounds, { double padding = 0 }) async {
    return _channel.invokeMethod<void>('map#fitBounds',
        <String, dynamic>{'bounds': bounds.toJson(), 'padding': padding});
  }

  Future<void> enable3DMode(bool isEnable) {
    return _channel.invokeMethod<bool>(
        'map#enable3DMode', <String, Object>{'enable3DMode': isEnable});
  }

  /// Updates configuration options of the map user interface.
  ///
  /// Change listeners are notified once the update has been made on the
  /// platform side.
  ///
  /// The returned [Future] completes after listeners have been notified.
  Future<void> _updateMapOptions(Map<String, dynamic> optionsUpdate) {
    assert(optionsUpdate != null);
    return _channel.invokeMethod<void>('map#update', <String, dynamic>{'options': optionsUpdate},
    );
  }
}

==> just_mf_map-0.0.3.tar.gz: lib/src/controller.dart <==
part of just_mf_map_flutter;

class MFMapViewController {
  final int mapId;
  final _MFMapViewState _mapState;
  final MethodChannel _channel;

  MFMapViewController._(this.mapId, this._mapState, this._channel) {
    _channel.setMethodCallHandler((call) => _handleMethodCall(call));
  }

  /// Initialize control of a [Map4d] with [mapId].
  ///
  /// Mainly for internal use when instantiating a [MFMapViewController] passed
  /// in [Map4dMap.onMapCreated] callback.
  static Future<MFMapViewController> init(
    int mapId,
    _MFMapViewState mapState,
  ) async {
    final channel = MethodChannel('plugin:map4d-map-view-type_$mapId');
    return MFMapViewController._(mapId, mapState, channel);
  }

  Future<dynamic> _handleMethodCall(MethodCall call) async {
    switch (call.method) {
      case 'camera#onMoveStarted':
        if (_mapState.widget.onCameraMoveStarted != null) {
          _mapState.widget.onCameraMoveStarted!();
        }
        break;
      case 'camera#onMove':
        if (_mapState.widget.onCameraMove != null) {
          final position = MFCameraPosition.fromMap(call.arguments['position']);
          _mapState.widget.onCameraMove!(position!);
        }
        break;
      case 'camera#onIdle':
        if (_mapState.widget.onCameraIdle != null) {
          _mapState.widget.onCameraIdle!();
        }
        break;
      case 'map#didTapAtCoordinate':
        if (_mapState.widget.onTap != null) {
          final coordinate = MFLatLng.fromJson(call.arguments['coordinate']);
          _mapState.widget.onTap!(coordinate!);
        }
        break;
      case 'map#onTapPOI':
        final onPOITap = _mapState.widget.onPOITap;
        if (onPOITap != null) {
          final String placeId = call.arguments['placeId'];
          final String name = call.arguments['name'];
          final MFLatLng location =
              MFLatLng.fromJson(call.arguments['location'])!;
          onPOITap(placeId, name, location);
        }
        break;
      case 'map#onTapBuilding':
        final onBuildingTap = _mapState.widget.onBuildingTap;
        if (onBuildingTap != null) {
          final String buildingId = call.arguments['buildingId'];
          final String name = call.arguments['name'];
          final MFLatLng location =
              MFLatLng.fromJson(call.arguments['location'])!;
          onBuildingTap(buildingId, name, location);
        }
        break;
      case 'map#onModeChange':
        final is3DMode = call.arguments['is3DMode'];
        _mapState.widget.onModeChange!(is3DMode);
        break;
      default:
        print('Unknow callback method: ${call.method}');
    }
  }

  /// Returns the current zoom level of the map
  Future<double> getZoomLevel() async {
    return (await _channel.invokeMethod<double>('map#getZoomLevel'))!;
  }

  Future<void> moveCamera(MFCameraUpdate cameraUpdate) {
    return _channel.invokeMethod<void>('camera#move',
        <String, dynamic>{'cameraUpdate': cameraUpdate.toJson()});
  }

  Future<void> animateCamera(MFCameraUpdate cameraUpdate) {
    return _channel.invokeMethod<void>('camera#animate',
        <String, Object>{'cameraUpdate': cameraUpdate.toJson()});
  }

  Future<MFCameraPosition> cameraForBounds(MFLatLngBounds bounds,
      {double padding = 0}) async {
    final Map<String, dynamic> cameraPosition = (await _channel
        .invokeMapMethod<String, dynamic>('map#cameraForBounds',
            <String, dynamic>{'bounds': bounds.toJson(), 'padding': padding}))!;
    return MFCameraPosition.fromMap(cameraPosition)!;
  }

  Future<MFCameraPosition?> getCameraPosition() async {
    final Map<String, dynamic> cameraPosition = (await _channel
        .invokeMapMethod<String, dynamic>('map#getCameraPosition'))!;
    return MFCameraPosition.fromMap(cameraPosition);
  }

  Future<void> fitBounds(MFLatLngBounds bounds, {double padding = 0}) async {
    return _channel.invokeMethod<void>('map#fitBounds',
        <String, dynamic>{'bounds': bounds.toJson(), 'padding': padding});
  }

  Future<void> enable3DMode(bool isEnable) {
    return _channel.invokeMethod<bool>(
        'map#enable3DMode', <String, Object>{'enable3DMode': isEnable});
  }

  /// Updates configuration options of the map user interface.
  ///
  /// Change listeners are notified once the update has been made on the
  /// platform side.
  ///
  /// The returned [Future] completes after listeners have been notified.
  Future<void> _updateMapOptions(Map<String, dynamic> optionsUpdate) {
    assert(optionsUpdate != null);
    return _channel.invokeMethod<void>(
      'map#update',
      <String, dynamic>{'options': optionsUpdate},
    );
  }
}
